( cd usr/lib64 ; rm -rf java )
( cd usr/lib64 ; ln -sf jre1.6.0_02 java )
( cd usr/lib64/jre1.6.0_02/man ; rm -rf ja )
( cd usr/lib64/jre1.6.0_02/man ; ln -sf ja_JP.eucJP ja )
( cd usr/lib64/jre1.6.0_02/lib/amd64/server ; rm -rf libjsig.so )
( cd usr/lib64/jre1.6.0_02/lib/amd64/server ; ln -sf ../libjsig.so libjsig.so )
